﻿
--===================================================
--									
--								GHI Options Menu
--								ghi_optionsMenu.lua
--									<< Singleton >>
--
--	Options menus for GHI, placed in the options menu tab	
--
-- 						(c)2011 The Gryphonheart Team
--								All rights reservated
--===================================================


local class;
function GHI_OptionsMenu()
	if class then
		return class;
	end
	class = GHClass("GHI_OptionsMenu");
	
	local mainMenuFrame,OnOk,OnShow,debugFrame,whiteListFrame,log,button,UpdateButton,bagButtonFrame,DefaultValues;
	
	
	log = GHI_Log();
	button = GHI_Button();
	button.SetChangePositionCallbackFunction(function(x,y)
		GHI_MiscData["BackpackPos"] = {x,y};
	end);
	
    DefaultValues = function()
        if not(GHI_MiscData["tooltip_version"] == false) then
            GHI_MiscData["tooltip_version"] = true;
        end
    end
    
	UpdateButton = function()
		button.SetScale(GHI_MiscData["BackpackScale"] or 1);
		
		if GHI_MiscData["BackpackPos"] then
			button.SetPosition(unpack(GHI_MiscData["BackpackPos"]));
		else
			button.ResetPosition();
		end
		
		if GHI_MiscData["BackpackIcon"] then
			button.SetTexture(GHI_MiscData["BackpackIcon"]);
		else
			button.SetTexture("Interface\\Icons\\INV_Misc_Bag_07_Blue");
		end
		
		if GHI_MiscData["BackpackType"] == 2 then
			button.UseRound();
		else
			button.UseSquared();
		end
	end
	UpdateButton();
	DefaultValues();
    
	class.Show = function()
		InterfaceOptionsFrame_OpenToCategory(mainMenuFrame);
		
		local i = 1;
		local f = _G["InterfaceOptionsFrameAddOnsButton"..i];
		while f and f.element do
            if f.element.name == GHI_FULL_NAME and string.lower(f.toggle:GetNormalTexture():GetTexture()) == string.lower("Interface\\Buttons\\UI-PlusButton-Up") then
				f.toggle:Click();
			end
			i = i + 1;
			f = _G["InterfaceOptionsFrameAddOnsButton"..i];
		end
	end
	
	OnOk = function()
		local main = mainMenuFrame;
		
	
		GHI_MiscData["BackpackScale"] = bagButtonFrame.GetLabel("icon_scale");
		GHI_MiscData["BackpackIcon"] = bagButtonFrame.GetLabel("icon");
		GHI_MiscData["BackpackType"] = bagButtonFrame.GetLabel("shape");
		UpdateButton();
		
		local show_warning = main.GetLabel("block_std_emote");
		
		if show_warning == 1 then
			GHI_MiscData["block_std_emote"] = true;
		else
			GHI_MiscData["block_std_emote"] = false;
		end
		
		GHI_MiscData["hide_empty_slots"] = main.GetLabel("hide_empty_slots");
		GHI_ShowSlots(false);
		
		GHI_MiscData["block_area_sound"] = main.GetLabel("block_area_sound");
		GHI_MiscData["block_area_buff"] = main.GetLabel("block_area_buff");
		GHI_MiscData["show_area_sound_sender"] = main.GetLabel("show_area_sound_sender");
		GHI_MiscData["stick_player_buffs"] = main.GetLabel("stick_player_buffs") or false;
		GHI_MiscData["stick_target_buffs"] = main.GetLabel("stick_target_buffs") or false;
		GHI_MiscData["no_channel_comm"] = main.GetLabel("no_channel_comm") or false;
        
        GHI_MiscData["tooltip_version"] = main.GetLabel("tooltip_version") or false;
        
        
        GHI_MiscData["WhiteList"] = {strsplit("\n",gsub(whiteListFrame.GetLabel("list").."\n"," ",""))};
        GHI_MiscData["target_icon_display_method"] = main.GetLabel("target_icon_display_method") or 1;
		
		
		GHI_UpdateBuffSticking()
		UpdateButton();
	end	
	
	OnShow = function()  
		--SetDefaultValues();
	
		
		whiteListFrame.ForceLabel("list",strjoin("\n",unpack(GHI_MiscData["WhiteList"] or {})));
	
		bagButtonFrame.ForceLabel("icon_scale",GHI_MiscData["BackpackScale"] or 1)
		
		
		if GHI_MiscData["BackpackType"] == 2 then
			bagButtonFrame.ForceLabel("shape",2);
		else
			bagButtonFrame.ForceLabel("shape",1);
		end
		
		if GHI_MiscData["BackpackIcon"] then
			bagButtonFrame.ForceLabel("icon", GHI_MiscData["BackpackIcon"]);
		else
			bagButtonFrame.ForceLabel("icon","Interface\\Icons\\INV_Misc_Bag_07_Blue");
		end
		
		local f = mainMenuFrame;
				
		local show_msg = GHI_MiscData["block_std_emote"];
		
		if show_msg == false then
			f.ForceLabel("block_std_emote",nil);
		else
			f.ForceLabel("block_std_emote",1);
			
		end
		
		
		f.ForceLabel("hide_empty_slots",GHI_MiscData["hide_empty_slots"]);
		f.ForceLabel("block_area_buff",GHI_MiscData["block_area_buff"]);
		f.ForceLabel("block_area_sound",GHI_MiscData["block_area_sound"]);
		f.ForceLabel("show_area_sound_sender",GHI_MiscData["show_area_sound_sender"]);
		f.ForceLabel("stick_player_buffs",GHI_MiscData["stick_player_buffs"]);
		f.ForceLabel("stick_target_buffs",GHI_MiscData["stick_target_buffs"]);
		f.ForceLabel("no_channel_comm",GHI_MiscData["no_channel_comm"]);
		f.ForceLabel("tooltip_version",GHI_MiscData["tooltip_version"]);
		f.ForceLabel("target_icon_display_method",GHI_MiscData["target_icon_display_method"]);
		
	end 
	
	
	
	-- Menu setup
	local version = GetAddOnMetadata("GHI","Version")
	
	mainMenuFrame = GHM_NewFrame(class,{
		onOk = function(self) end,
		{
			{
				{
					align = "c",
					type = "Text",
					text = format("%s v. %s",GHI_FULL_NAME,version or "unknown");
					fontSize = 14,
				}, 
			}, 
			{
				{
					align = "c",
					type = "Text",
					text = GHI_HELP_CREDITS,
					fontSize = 11,
				}, 
			},
			{
				{
					height = 12,
					type = "Dummy",
					align = "c",
					width = 10,
				}, 
			}, 
			{
				{
					fontSize = 11,
					color = "white",
					text = GHI_HELP_ADD_INFO,
					align = "l",
					type = "Text",
				},
			}, 
			{
				{
					height = 20,
					type = "Dummy",
					align = "c",
					width = 10,
				},
			},  
			{
				{
					align = "l",
					type = "CheckBox",
					text = GHI_BLOCK_STD_EMOTE,
					label = "block_std_emote",
				}, 
				{
					type = "Button",
					label = "center_buff",
					align = "r",
					text = GHI_CENTER_BUFFS,
					compact = false,
					onclick = function(self)
						GHU_BuffResetAllPositions(self);	
					end,
				}, 
			}, 
			{
				{
					align = "l",
					type = "CheckBox",
					text = GHI_HIDE_EMPTY_SLOTS,
					label = "hide_empty_slots",
				}, 
				{
					type = "Button",
					label = "remove_buffs",
					align = "r",
					text = GHI_REMOVE_BUFFS,
					compact = false,
					onclick = function(self)
						RemoveAllGHIBuffs()	
					end,
				}, 
			}, 
			{
				{
					align = "l",
					type = "CheckBox",
					text = GHI_BLOCK_AREA_SOUND,
					label = "block_area_sound",
				}, 
			}, 
			{
				{
					align = "l",
					type = "CheckBox",
					text = GHI_BLOCK_AREA_BUFFS,
					label = "block_area_buff",
				},
				{
					type = "CustomDD",
					text = "Target button display",
					align = "r",
					label = "target_icon_display_method",
					returnIndex = true,
					data = {"All friendly","All confirmed GHI users","Always hide"},
				},
			}, 
			{
				{
					align = "l",
					type = "CheckBox",
					text = GHI_SHOW_AREA_SOUND_SENDER,
					label = "show_area_sound_sender",
				}, 
			},
			{
				{
					align = "l",
					type = "CheckBox",
					text = GHI_STICK_PLAYER_BUFFS,
					label = "stick_player_buffs",
				}, 
			},
            {
				{
					align = "l",
					type = "CheckBox",
					text = GHI_STICK_TARGET_BUFFS,
					label = "stick_target_buffs",
				}, 
			},
			{
				{
					align = "l",
					type = "CheckBox",
					text = GHI_NO_CHANNEL_COMM,
					label = "no_channel_comm",
				}, 
			},
            {
				{
					align = "l",
					type = "CheckBox",
					text = GHI_TOOLTIP_VERSION,
					label = "tooltip_version",
				}, 
			},
		}, 
		title = GHI_HELP_TITLE,
		height = 400,
		name = "GHI_Help_Menu_Frame",
		theme = "BlankTheme",
		width = 490,	
	});
	
	mainMenuFrame.name = GHI_FULL_NAME;
	mainMenuFrame.okay = OnOk;
	mainMenuFrame.refresh = OnShow;
		
	InterfaceOptions_AddCategory(mainMenuFrame);
	
	bagButtonFrame = GHM_NewFrame(CreateFrame("frame"),{
		onOk = function(self) end,
		{
			{
				{
					align = "c",
					type = "Text",
					text = GHI_HELP_BACKPACK_ICON,
					fontSize = 11,
				}, 
			}, 
			{
				{
					height = 20,
					type = "Dummy",
					align = "c",
					width = 10,
				},
			},  
			{
				{
					height = 20,
					type = "Dummy",
					align = "l",
					width = 20,
				},
				{
					type = "CustomDD",
					text = "Icon Shape",
					align = "l",
					label = "shape",
					returnIndex = true,
					data = {"Squared","Round"},
				},
				{
					height = 20,
					type = "Dummy",
					align = "r",
					width = 60,
				},
				{
					type = "Icon",
					text = GHI_ICON,
					align = "r",
					label = "icon",
					framealign = "r",
					CloseOnChoosen = true,
				},
			},
			{
				{
					height = 20,
					type = "Dummy",
					align = "c",
					width = 10,
				},
			}, 
			{ 
				{
					height = 20,
					type = "Dummy",
					align = "l",
					width = 30,
				},
				{
					type = "CustomSlider",
					values = {0.25,0.5,0.75,1.00,1.25,1.50,1.75,2.00},
					label = "icon_scale",
					align = "l",
					text = GHI_SCALE,
				},
				{
					height = 20,
					type = "Dummy",
					align = "r",
					width = 40,
				},
				{
					type = "Button",
					label = "center_icon",
					align = "r",
					text = GHI_CENTER_ICON,
					compact = false,
					onclick = function(self)
						button.ResetPosition();
					end,
				},
			},
		}, 
		OnShow = function() 
			
		end,
		title = "",
		height = 400,
		name = "GHI_OptionsButtonFrame",
		theme = "BlankTheme",
		width = 500,	
	});
	
	bagButtonFrame.name = GHI_HELP_BACKPACK_ICON;
	bagButtonFrame.okay = function() end;
	bagButtonFrame.parent = mainMenuFrame.name;
			
	InterfaceOptions_AddCategory(bagButtonFrame);
	
	
    whiteListFrame = GHM_NewFrame(CreateFrame("frame"),{
		onOk = function(self) end,
		{
			{
				{
					align = "c",
					type = "Text",
					text = "Personal Script Whitelist",
					fontSize = 13,
				}, 
			},
            {
                {
                    height = 40,
                    type = "Dummy",
                    align = "r",
                    width = 20,
			    },
            },
            {
				{
					align = "l",
					type = "Text",
                    color = "white",
					text = "Non whitelisted global variables can be whitelisted by adding them to this list. The white list is personal, a script with a non whitelisted function can only run as intended by players with the function on their whitelist.",
					fontSize = 11,
				}, 
			},
            {
                {
                    height = 40,
                    type = "Dummy",
                    align = "r",
                    width = 20, 
			    },
            },
            {
				{
					align = "l",
					type = "Text",
                    color = "white",
					text = "A reload of the UI might be required for changes to take effect. Only one variable pr line.\nBe cautious, as some non whitelisted functions can be dangerous and open access to damaging items.",
					fontSize = 11,
				}, 
			},
            {
                {
                    height = 40,
                    type = "Dummy",
                    align = "r",
                    width = 10, 
			    },
            },
			{
				{
					type = "EditField",
					align = "c",
					height = InterfaceOptionsFrame:GetHeight()-300,
					width = 350,
					label = "list",
				},
			},
		}, 
		OnShow = function() 
			
		end,
		title = "Personal Whitelist",
		height = 400,
		name = "GHI_OptionsWhiteListFrame",
		theme = "BlankTheme",
		width = 490,	
	});
	
	
	whiteListFrame.name = "Personal Whitelist";
	whiteListFrame.okay = function() end;
	whiteListFrame.parent = mainMenuFrame.name;
			
	InterfaceOptions_AddCategory(whiteListFrame);
    
    
    
	debugFrame = GHM_NewFrame(CreateFrame("frame"),{
		onOk = function(self) end,
		{
			{
				{
					align = "c",
					type = "Text",
					text = "GHI Debug Event Log",
					fontSize = 11,
				}, 
			}, 
			{
				{
					type = "EditField",
					align = "c",
					height = 400,
					width = 350,
					label = "log",
				},
			},
		}, 
		OnShow = function() 
			debugFrame.ForceLabel("log",log.ToText());
		end,
		title = "Debug Event Log",
		height = 400,
		name = "GHI_OptionsDebugFrame",
		theme = "BlankTheme",
		width = 490,	
	});
	
	_G[debugFrame.GetLabelFrame("log"):GetName().."ScrollText"]:SetMaxLetters(50000);
	
	debugFrame.name = "Debug Event Log";
	debugFrame.okay = function() end;
	debugFrame.parent = mainMenuFrame.name;
			
	InterfaceOptions_AddCategory(debugFrame);
	
	return class;
end

